/*
 * Copyright 2017-present Open Networking Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.onosproject.incubator.net.routing;

import java.util.Objects;

/**
 * Identifier for an EVPN routing table.
 */
public class EvpnRouteTableId {
    private final String name;

    /**
     * Creates a new route table ID.
     *
     * @param name unique name for the route table
     */
    public EvpnRouteTableId(String name) {
        this.name = name;
    }

    /**
     * Returns the name of the route table.
     *
     * @return table name
     */
    public String name() {
        return name;
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }

        if (obj instanceof EvpnRouteTableId) {
            EvpnRouteTableId that = (EvpnRouteTableId) obj;

            return Objects.equals(this.name, that.name);
        }
        return false;
    }

    @Override
    public int hashCode() {
        return Objects.hash(name);
    }

    @Override
    public String toString() {
        return name;
    }
}
